@@ -13,14 +13,13 @@
 #' is_incomplete_terms(term("b[2]", "b[1]"))
 #' is_incomplete_terms(term("b[2]", "b[1]", "b[1]"))
 is_incomplete_terms <- function(x, ...) {
+  x <- as_term(x)
   if (!length(x)) {
     return(FALSE)
   }
   if (anyNA(x)) {
     return(NA)
   }
-  if(length(unique(table(x))) != 1L)
-    return(TRUE)
   x <- unique(x)
   length(x) < sum(vapply(pdims(x), prod, 1))
 }
